@@ -7,7 +7,7 @@ class ADSLData:
         service_subdivision, service_subdivision_code, shipment_address, shipment_city, shipment_zip,
         shipment_subdivision, previous_service, previous_provider, previous_internal_provider,
         previous_owner_vat, previous_owner_name, previous_owner_surname, notes,
-            adsl_coverage, mm_fiber_coverage, vdf_fiber_coverage, change_address, product,
+            adsl_coverage, mm_fiber_coverage, vdf_fiber_coverage, orange_fiber_coverage, change_address, product,
             previous_contract_address="", previous_contract_phone=""):
         # Common all the Tickets
         self.order_id = order_id
@@ -35,6 +35,7 @@ class ADSLData:
         self.adsl_coverage = adsl_coverage
         self.mm_fiber_coverage = mm_fiber_coverage
         self.vdf_fiber_coverage = vdf_fiber_coverage
+        self.orange_fiber_coverage = orange_fiber_coverage
         self.change_address = change_address
         self.previous_contract_address = previous_contract_address
         self.previous_contract_phone = previous_contract_phone
