@@ -1,8 +1,7 @@
 class CustomerData:
-    def __init__(self, id, vat_number, email, phone, name, first_name, street, city, zip, subdivision):
+    def __init__(self, id, vat_number, phone, name, first_name, street, city, zip, subdivision):
         self.id = id
         self.vat_number = vat_number
-        self.email = email
         self.phone = phone
         self.name = name
         self.first_name = first_name
