@@ -27,6 +27,7 @@ class InternetDynamicFields(ProvisionDynamicFields):
             self._previous_owner_vat(),
             self._adsl_coverage(),
             self._mm_fiber_coverage(),
+            self._orange_fiber_coverage(),
             self._vdf_fiber_coverage(),
             self._change_address(),
             self._change_address_provider(),
@@ -94,6 +95,12 @@ class InternetDynamicFields(ProvisionDynamicFields):
             value=self.service_data.vdf_fiber_coverage
         )
 
+    def _orange_fiber_coverage(self):
+        return DynamicField(
+            name="coberturaFibraOrange",
+            value=self.service_data.orange_fiber_coverage
+        )
+
     def _previous_contract_phone(self):
         return DynamicField(name="telefonFixAntic", value=self.service_data.previous_contract_phone)
 
