@@ -67,6 +67,10 @@ class MobileProcessTicket:
     def icc(self):
         return self.response.dynamic_field_get('ICCSC').value
 
+    @property
+    def has_sim(self):
+        return self.response.dynamic_field_get('noCobrarSIM').value
+
     @property
     def iban(self):
         return self.response.dynamic_field_get('IBAN').value
