@@ -23,9 +23,11 @@ class ProvisionDynamicFields():
             self._mail(),
             self._previous_owner_name(),
             self._previous_owner_surname1(),
+            self._previous_owner_full_name(),
             self._product(),
         ]
         dynamic_fields += self._build_specific_dynamic_fields()
+
         return [field for field in dynamic_fields if field.value]
 
     def _process_id(self):
@@ -63,3 +65,16 @@ class ProvisionDynamicFields():
             name="cognom1Titular",
             value=self.service_data.previous_owner_surname
         )
+
+    def _previous_owner_full_name(self):
+        full_name = ""
+        if (hasattr(self.service_data, 'change_address')
+                and self.service_data.change_address == "yes"):
+            full_name = "{} {}".format(
+                self.service_data.previous_owner_name,
+                self.service_data.previous_owner_surname
+            )
+        return DynamicField(
+            name="nomCognomSociAntic",
+            value=full_name
+        )
