@@ -31,7 +31,8 @@ class ADSLDataTestCase(unittest.TestCase):
             adsl_coverage=None,
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
-            type="location_change",
+            orange_fiber_coverage=None,
+            change_address="no",
             landline_phone_number="landline_phone_number",
             product="product"
         )
