@@ -50,6 +50,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
+            'orange_fiber_coverage',
             'change_address',
             'product',
             'previous_internal_provider',
@@ -380,7 +381,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaADSL"], "20")
 
     def test_mm_fiber_coverage_field(self):
-        self.service_data.mm_fiber_coverage = "CoberturaMM"
+        self.service_data.mm_fiber_coverage = "fibraFTTH"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
@@ -390,10 +391,10 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["coberturaFibraMM"], "CoberturaMM")
+        self.assertEqual(dynamic_fields_dct["coberturaFibraMM"], "fibraFTTH")
 
     def test_vdf_fiber_coverage_field(self):
-        self.service_data.vdf_fiber_coverage = "FibraVdf"
+        self.service_data.vdf_fiber_coverage = "fibraFTTH"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
@@ -403,7 +404,20 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
+        self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "fibraFTTH")
+
+    def test_orange_fiber_coverage_field(self):
+        self.service_data.orange_fiber_coverage = "fibraFTTH"
+
+        dynamic_fields = ADSLDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["coberturaFibraOrange"], "fibraFTTH")
 
     def test_change_address_field(self):
         self.service_data.change_address = "yes"
