@@ -51,6 +51,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
             'adsl_coverage',
             'mm_fiber_coverage',
             'vdf_fiber_coverage',
+            'orange_fiber_coverage',
             'change_address',
             'product',
             'previous_internal_provider',
@@ -446,7 +447,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["coberturaADSL"], "20")
 
     def test_mm_fiber_coverage_field(self):
-        self.service_data.mm_fiber_coverage = "CoberturaMM"
+        self.service_data.mm_fiber_coverage = "fibraFTTH"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -456,10 +457,10 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["coberturaFibraMM"], "CoberturaMM")
+        self.assertEqual(dynamic_fields_dct["coberturaFibraMM"], "fibraFTTH")
 
     def test_vdf_fiber_coverage_field(self):
-        self.service_data.vdf_fiber_coverage = "FibraVdf"
+        self.service_data.vdf_fiber_coverage = "fibraFTTH"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -469,7 +470,20 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "FibraVdf")
+        self.assertEqual(dynamic_fields_dct["coberturaFibraVdf"], "fibraFTTH")
+
+    def test_orange_fiber_coverage_field(self):
+        self.service_data.orange_fiber_coverage = "fibraFTTH"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.adsl_otrs_process_id,
+            self.adsl_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["coberturaFibraOrange"], "fibraFTTH")
 
     def test_change_address_field(self):
         self.service_data.change_address = "yes"
