@@ -43,7 +43,7 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
             'previous_owner_surname',
             'previous_provider',
             'product',
-            'type',
+            'has_sim',
         ])
         self.mobile_data.portability = False
 
@@ -176,6 +176,45 @@ class MobileDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["tipusServeiMobil"], "portabilitat")
 
+    def test_service_has_sim_field_true(self):
+        self.mobile_data.has_sim = True
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertTrue(dynamic_fields_dct["noCobrarSIM"])
+
+    def test_service_send_sim_type_has_sim_true(self):
+        self.mobile_data.has_sim = True
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["tipusEnviamentSIM"], "None")
+
+    def test_service_send_sim_type_has_sim_false(self):
+        self.mobile_data.has_sim = False
+
+        dynamic_fields = MobileDynamicFields(
+            self.mobile_data,
+            self.customer_data,
+            self.mobile_otrs_process_id,
+            self.mobile_otrs_activity_id
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(dynamic_fields_dct["tipusEnviamentSIM"], "CH_SC_OSO_SIM")
+
     def test_IBAN_field(self):
         self.mobile_data.iban = "ES6621000418401234567891"
 
